~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ISO-20022 plugin for ofxstatement
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. image:: https://travis-ci.org/kedder/ofxstatement-iso20022.svg?branch=master
    :target: https://travis-ci.org/kedder/ofxstatement-iso20022

Plugin to read ISO-20022 formatted statements.

Currently implementation is very trivial and naive. If it doesn't work for
you, feel free to improve it or file a bug on github with sample (anonymized)
state file.
